<?php

require_once('../model/FETemplateModel.php');//any model classes being used
require_once('../model/FEPageModel.php');
require_once('../model/FEAreaModel.php');
require_once('../model/FEArticleModel.php');
require_once('LogoutController.php');//any other controllers being invoked
require_once('FrontLoginController.php');

//displays pages for the public
//allows authors to sign in and post / edit
class FrontEndController 
{
    //doing $this-> already makes these class level
    //but it doesn't hurt to be explicit
    private $page_model;
    private $area_model;
    private $article_model;
    private $template_model;
    
    //constructor: set up our models
    public function __construct()
    {
        $this->template_model = new FETemplateModel();
        $this->page_model = new FEPageModel();
        $this->area_model = new FEAreaModel();
        $this->article_model = new FEArticleModel();
    }
    
    //fired on loads of index.php
    //all get / post logic is handled here
    public function invoke()
    {
         session_start();
         //handles logouts from CManager (they land here)
         if (isset($_GET['logout']) && !isset($_SESSION['alreadylo']))
         {
             if ($_SESSION['alreadylo'] == true)
                 $_SESSION['alreadylo'] = false;
             $logOut = new LogoutController();
             $logOut->invoke();
         }
         
         //logic for frontend user sign-in
         if (isset($_POST['SignInBtn']))
         {
             $_SESSION['auname'] = $_POST['auname'];
             $_SESSION['apassword'] = $_POST['apassword'];
             $goLogin = new FrontLoginController();
             $goLogin->invoke();
         }
         if (isset($_GET['SignOutBtn']))
         {
             if ($_SESSION['alreadylo'] == true)
                 $_SESSION['alreadylo'] = false;
             $logOut = new LogoutController();
             $logOut->revoke();
         }
         //flag controlling if either sign in fields or add article / logout buttons displayed:
         $authauth = "";
         if (isset($_SESSION['authauth']))
         {
             if ($_SESSION['authauth'] == true)
                 $authauth = true;             
         }
         else
             $authauth = false;
        
         //get template (its CSS directives appear inline in the view)
         $template = $this->template_model->fetchTemplate();

         //get page
         if(!isset($_GET['page']))
         {
             //get page 1
             $page = $this->page_model->fetchPage("page1");
         }
         else
         {
             //get requested page
             $page = $this->page_model->fetchPage($_GET['page']);
             
         }

         //get content areas
         $areas = $this->area_model->fetchAreas();

         //get articles for the page name & for the ones that appear on all pages
         $articles = $this->article_model->fetchArticles($page->getName());

         $auser = "";
         $msg = "";
         //$auser or 'auname' could be used to fill in the username box
         //after a failed login (not able to do that with this implementation, though)
         if (isset($_SESSION['auname']))
             $auser = $_SESSION['auname'];
         //'alomsg' holds login errors for display
         if (isset($_SESSION['alomsg']))
             $msg = $_SESSION['alomsg'];
         
         //author clicks "EDIT" on an article
         if(isset($_GET['editarticle']))
         {
             if ($authauth)
             {
             $article = $this->article_model->fetchArticle($_GET['editarticle']);
             include '../view/fronteditor/editarticle.phtml';
             }
             else
             {
                $msg = "Not signed in.";
                include '../view/visitors/index.phtml';
             }

         }
         
         //author clicks "Add" button under "Articles:"
         else if(isset($_GET['AddArticleBtn']))
         {

             if ($authauth)
             include '../view/fronteditor/newarticle.phtml';
             else
             {
                $msg = "Not signed in.";
                include '../view/visitors/index.phtml';
             }

         }

         //author finalizes thons edits
         else if (isset($_POST['EditArticleBtn']))
         {
             //do article edit stuff:
             $this->article_model->editArticle($_SESSION['auname'], $_POST['oname'], $_POST['name'],$_POST['title'],$_POST['description'],$_POST['page'],$_POST['area'],$_POST['body']);

             //back to main screen:
             
             //get template
             $template = $this->template_model->fetchTemplate();

             //get the page showing the updated article
             if ($_POST['page'] != "")
             $page = $this->page_model->fetchPageDirect($_POST['page']);
             else
             $page = $this->page_model->fetchPage("page1");

             //get content areas
             $areas = $this->area_model->fetchAreas();

             //get articles for the page name & for all pages
             $articles = $this->article_model->fetchArticles($page->getName());

             $msg = "Article \"" . $_POST['name'] . "\" modified successfully.";
             //show view
             include '../view/visitors/index.phtml';
         }
         
         //author finalizes a new article
         else if (isset($_POST['NewArticleBtn']))
         {
             //do insert article stuff:
             $this->article_model->insertArticle($_SESSION['auname'], $_POST['name'],$_POST['title'],$_POST['description'],$_POST['page'],$_POST['area'],$_POST['body']);

             //back to main screen:
             
             //get template
             $template = $this->template_model->fetchTemplate();

             //get the page showing the new article
             if ($_POST['page'] != "")
             $page = $this->page_model->fetchPageDirect($_POST['page']);
             else
             $page = $this->page_model->fetchPage("page1");

             //get content areas
             $areas = $this->area_model->fetchAreas();

             //get articles for the page name & for all pages
             $articles = $this->article_model->fetchArticles($page->getName());

             $msg = "Article \"" . $_POST['name'] . "\" created successfully.";
             //show view
             include '../view/visitors/index.phtml';
         }
         
         //if nothing else to do, just show the view
         else
         {
         include '../view/visitors/index.phtml';
         }
         
    }
        

}

?>
